@@ -4,12 +4,15 @@ use strict;
 use warnings;
 use Test::Classy::Base;
 use CLIDTest::Error;
+use Try::Tiny;
 
 sub simple_dispatch : Test {
   my $class = shift;
 
   my $ret = $class->dispatch(qw( simple ));
 
+  return $class->abort_this_test('obscure error') if $ret eq 'Obscure error';
+
   ok $ret =~ /Compilation failed/, $class->message("dispatch succeeded: $ret");
 }
 
@@ -18,6 +21,8 @@ sub simple_with_args : Test {
 
   my $ret = $class->dispatch(qw( with_args one two three ));
 
+  return $class->abort_this_test('obscure error') if $ret eq 'Obscure error';
+
   ok $ret =~ /Compilation failed/, $class->message("dispatch succeeded: $ret");
 }
 
@@ -26,6 +31,8 @@ sub simple_with_options : Test {
 
   my $ret = $class->dispatch(qw( WithOptions --hello --target=world ));
 
+  return $class->abort_this_test('obscure error') if $ret eq 'Obscure error';
+
   ok $ret =~ /Compilation failed/, $class->message("dispatch succeeded: $ret");
 }
 
@@ -35,9 +42,10 @@ sub dispatch {
   local @ARGV = @_;
 
   my $ret;
-  eval { $ret = CLIDTest::Error->run };
+  try   { $ret = CLIDTest::Error->run }
+  catch { $ret = $_ || 'Obscure error' };
 
-  return $@ ? $@ : $ret;
+  return $ret;
 }
 
 1;
